@@ -8,7 +8,7 @@ import constants.constants as bdb_constants
 from utils.utils import Utils
 
 
-AllowedProvider = Literal["openai"]
+AllowedProvider = Literal["openai", "anthropic"]
 
 
 @dataclass(frozen=True)
@@ -18,7 +18,7 @@ class LLMAgent:
     temperature: float
     system_prompt: str
 
-    def chat(self, llm_api_key: str, prompt_args: dict[str, str] | None = None) -> dict:
+    def chat(self, llm_api_key: str, prompt_args: dict[str, str] | None = None, attachment_args: dict | None = None) -> dict:
         """
         Send a chat message to the BERRY_GPT service using this prompt configuration.
 
@@ -27,6 +27,8 @@ class LLMAgent:
         - **prompt_args** (dict[str, str] | None, optional): Dictionary of key-value pairs to replace variables in system_prompt.
           Variables should be enclosed with {{variable}} in the system_prompt.
           Example: {"user": "John"} will replace {{user}} with "John" in the system_prompt.
+        - **attachment_args** (dict | None, optional): Dictionary of additional arguments to be spread into the payload.
+          These arguments will be merged with the base payload at the top level.
 
         Returns:
         - dict: The response from the BERRY_GPT service.
@@ -38,19 +40,39 @@ class LLMAgent:
         Example:
         ```python
         from berrydb import LLMAgent
-
-        # Create a prompt configuration
-        prompt = LLMAgent.Builder() \
-            .provider("openai") \
-            .model("gpt-4o-mini") \
-            .temperature(0.7) \
-            .system_prompt("Hello {{user}}! You are a helpful assistant.") \
+        
+        # Create a prompt configuration with OpenAI
+        prompt = LLMAgent.Builder()\\
+            .provider("openai")\\
+            .model("gpt-4o-mini")\\
+            .temperature(0.7)\\
+            .system_prompt("Hello {{user}}! You are a helpful assistant.")\\
             .build()
 
         # Send a chat message with variable replacement
         response = prompt.chat("sk-your-openai-api-key", {"user": "John"})
         # Result: system_prompt becomes "Hello John! You are a helpful assistant."
         print(response)
+        
+        # Send a chat message with attachment arguments
+        response_with_attachments = prompt.chat(
+            "sk-your-openai-api-key", 
+            {"user": "John"}, 
+            {"attachmentType": "image", "attachmentUrl": "https://example.com/image.png"}
+        )
+        print(response_with_attachments)
+        
+        # Create a prompt configuration with Anthropic Claude
+        claude_prompt = LLMAgent.Builder()\\
+            .provider("anthropic")\\
+            .model("claude-sonnet-4-latest")\\
+            .temperature(0.7)\\
+            .system_prompt("Hello {{user}}! You are a helpful assistant.")\\
+            .build()
+        
+        # Send a chat message with Claude
+        claude_response = claude_prompt.chat("sk-your-anthropic-api-key", {"user": "John"})
+        print(claude_response)
         ```
         """
         # Enhanced validation: check for empty, None, or whitespace-only strings
@@ -82,6 +104,10 @@ class LLMAgent:
             }
         }
 
+        # Spread attachment_args into the payload if provided
+        if attachment_args and isinstance(attachment_args, dict):
+            payload.update(attachment_args)
+
         # Make the API call to the BERRY_GPT service
         api_url = bdb_constants.BERRY_GPT_BASE_URL + "/prompt-answer"
 
@@ -221,23 +247,47 @@ class LLMAgent:
         provider = prompt_data.get('llmProvider')
         if not provider or not isinstance(provider, str):
             provider = 'openai'  # Use default if invalid
-
+        elif provider not in ("openai", "anthropic"):
+            provider = 'openai'  # Use default if invalid provider
+        
         model = prompt_data.get('llmModel')
         if not model or not isinstance(model, str):
-            model = 'gpt-4o-mini'  # Use default if invalid
-
+            # Use provider-specific default model
+            if provider == "anthropic":
+                model = bdb_constants.DEFAULT_ANTHROPIC_MODEL
+            else:
+                model = bdb_constants.DEFAULT_OPEN_AI_MODEL
+        elif provider == "anthropic" and not model.startswith("claude"):
+            # Validate that Anthropic provider uses Claude models
+            model = bdb_constants.DEFAULT_ANTHROPIC_MODEL
+        elif provider == "openai" and not model.startswith("gpt"):
+            # Validate that OpenAI provider uses GPT models
+            model = bdb_constants.DEFAULT_OPEN_AI_MODEL
+        
         temperature = prompt_data.get('temperature')
         if temperature is None:
-            temperature = 0.5  # Use default if None
+            # Use provider-specific default temperature
+            if provider == "anthropic":
+                temperature = bdb_constants.DEFAULT_ANTHROPIC_TEMPERATURE
+            else:
+                temperature = bdb_constants.DEFAULT_OPEN_AI_TEMPERATURE
         else:
             # Try to convert to float, accepting strings, ints, and floats
             try:
                 temperature = float(temperature)
                 if not 0.0 <= temperature <= 1.0:
-                    temperature = 0.5  # Use default if out of range
+                    # Use provider-specific default if out of range
+                    if provider == "anthropic":
+                        temperature = bdb_constants.DEFAULT_ANTHROPIC_TEMPERATURE
+                    else:
+                        temperature = bdb_constants.DEFAULT_OPEN_AI_TEMPERATURE
             except (ValueError, TypeError):
-                temperature = 0.5  # Use default if conversion fails
-
+                # Use provider-specific default if conversion fails
+                if provider == "anthropic":
+                    temperature = bdb_constants.DEFAULT_ANTHROPIC_TEMPERATURE
+                else:
+                    temperature = bdb_constants.DEFAULT_OPEN_AI_TEMPERATURE
+        
         system_prompt = prompt_data.get('systemPrompt')
         if not isinstance(system_prompt, str):
             system_prompt = ''  # Use default if invalid
@@ -252,8 +302,13 @@ class LLMAgent:
     class Builder:
         def __init__(self):
             self._provider: AllowedProvider = bdb_constants.DEFAULT_PROVIDER  # type: ignore[assignment]
-            self._model: str = bdb_constants.DEFAULT_OPEN_AI_MODEL
-            self._temperature: float = bdb_constants.DEFAULT_OPEN_AI_TEMPERATURE
+            # Set appropriate default model and temperature based on provider
+            if self._provider == "anthropic":
+                self._model: str = bdb_constants.DEFAULT_ANTHROPIC_MODEL
+                self._temperature: float = bdb_constants.DEFAULT_ANTHROPIC_TEMPERATURE
+            else:
+                self._model: str = bdb_constants.DEFAULT_OPEN_AI_MODEL
+                self._temperature: float = bdb_constants.DEFAULT_OPEN_AI_TEMPERATURE
             self._system_prompt: str = ""
 
         def provider(self, provider: str | None = "openai") -> "LLMAgent.Builder":
@@ -274,9 +329,18 @@ class LLMAgent:
             # Enhanced validation with better error messages
             if not provider or not isinstance(provider, str):
                 raise ValueError("Provider must be a non-empty string")
-            if provider not in ("openai",):
-                raise ValueError(f'Invalid provider "{provider}", only "openai" is supported')
+            if provider not in ("openai", "anthropic"):
+                raise ValueError(f'Invalid provider "{provider}", only "openai" and "anthropic" are supported')
             self._provider = provider  # type: ignore[assignment]
+            
+            # Set appropriate default model and temperature based on provider
+            if provider == "anthropic":
+                self._model = bdb_constants.DEFAULT_ANTHROPIC_MODEL
+                self._temperature = bdb_constants.DEFAULT_ANTHROPIC_TEMPERATURE
+            else:  # openai
+                self._model = bdb_constants.DEFAULT_OPEN_AI_MODEL
+                self._temperature = bdb_constants.DEFAULT_OPEN_AI_TEMPERATURE
+            
             return self
 
         def model(self, model: str | None = None) -> "LLMAgent.Builder":
@@ -290,7 +354,11 @@ class LLMAgent:
             - `LLMAgent.Builder`: The builder instance for method chaining.
             """
             if model is None:
-                model = bdb_constants.DEFAULT_OPEN_AI_MODEL
+                # Use provider-specific default model
+                if self._provider == "anthropic":
+                    model = bdb_constants.DEFAULT_ANTHROPIC_MODEL
+                else:
+                    model = bdb_constants.DEFAULT_OPEN_AI_MODEL
             # Enhanced validation
             if not isinstance(model, str):
                 raise ValueError("Model must be a string")
@@ -316,7 +384,11 @@ class LLMAgent:
             - ValueError: If the temperature is outside the valid range of 0.0 to 1.0.
             """
             if temperature is None:
-                temperature = bdb_constants.DEFAULT_OPEN_AI_TEMPERATURE
+                # Use provider-specific default temperature
+                if self._provider == "anthropic":
+                    temperature = bdb_constants.DEFAULT_ANTHROPIC_TEMPERATURE
+                else:
+                    temperature = bdb_constants.DEFAULT_OPEN_AI_TEMPERATURE
             # Enhanced validation with better error handling
             try:
                 temperature = float(temperature)
