@@ -111,6 +111,9 @@ DEFAULT_OPEN_AI_EMBEDDING_MODEL = "text-embedding-3-small"
 DEFAULT_OPEN_AI_MODEL = "gpt-4o-mini"
 DEFAULT_OPEN_AI_TEMPERATURE = 0.5
 OPEN_AI_MODEL_TYPE_NAME = "OpenAI"
+DEFAULT_ANTHROPIC_MODEL = "claude-sonnet-4-latest"
+DEFAULT_ANTHROPIC_TEMPERATURE = 0.5
+ANTHROPIC_MODEL_TYPE_NAME = "Anthropic"
 HUGGING_FACE_MIXTRAL_MODEL = "Mixtral 7B Instruct v0.2"
 HUGGING_FACE_MIXTRAL_MODEL_ID = "mistralai/Mistral-7B-Instruct-v0.1"
 HUGGING_FACE_LLAMA_MODEL = "LLama 2 7b chat"
