@@ -1644,32 +1644,27 @@ class Database:
         model_args: Optional[Dict[str, Any]] = None,
     ) -> None:
         """
-        Annotate documents using either a model name OR a task name (exclusively).
+        Annotate documents using either a model name OR a task name.
 
-        Rules
-        -----
-        - Exactly one of `model_name` or `task_name` must be provided.
-        - If `model_name` is provided, it is used as-is (exact match).
-        - If `task_name` is provided, the backend resolves it to the correct model.
+        This method fetches documents, extracts data from a specified JSON path, invokes a model to get predictions, and adds the predictions as annotations back to the documents.
 
-        Parameters
-        ----------
-        **json_path** : (`str`)
-            JSON path to extract data for prediction.
-        **model_name** : (`str`, optional)
-            Exact model name (takes precedence; mutually exclusive with task_name).
-        **task_name** : (`str`, optional)
-            Logical task name (mutually exclusive with model_name).
-        **model_args** : (`dict`, optional)
-            Extra arguments to pass to the model (forwarded if task_name is used).
+        .. note::
+        **Rules**
+        - `model_name` takes precedence if both `model_name` and `task_name` are provided.
+        - If only `task_name` is provided, the backend resolves it to the correct model.
+        - At least one of `model_name` or `task_name` must be provided.
 
-        Raises
-        ------
-        ValueError
-            If json_path missing, or both/neither of model_name/task_name are provided,
-            or model_args is not dict/None.
-        RuntimeError
-            If the resolved model is not found.
+        **Parameters**
+        - **json_path** (`str`): JSON path to extract data for prediction.
+        - **model_name** (`str`, optional): Exact model name (takes precedence if provided).
+        - **task_name** (`str`, optional): Logical task name (resolved to a model if `model_name` not given).
+        - **model_args** (`dict`, optional): Extra arguments to pass to the model.
+
+        **Raises**
+        - **ValueError** - If `json_path` is missing or `model_args` is not dict/None.
+        - **Exception** - If no matching model is found.
+
+        ---
         """
         if not json_path:
             raise ValueError("json_path is required.")
@@ -1677,15 +1672,14 @@ class Database:
         if model_args is not None and not isinstance(model_args, dict):
             raise ValueError("model_args must be None or a dictionary.")
 
-        # XOR: exactly one of model_name / task_name
-        if bool(model_name) == bool(task_name):
-            raise ValueError("Provide exactly one of model_name or task_name (not both).")
+        if not model_name and not task_name:
+            raise ValueError("Either model_name or task_name must be provided.")
 
         # Resolve model name
-        if task_name:
-            resolved_model_name = self.__resolve_model_name_from_backend(task_name, model_args or {})
-        else:
+        if model_name:
             resolved_model_name = model_name
+        else:
+            resolved_model_name = self.__resolve_model_name_from_backend(task_name, model_args or {})
 
         model_repo = ModelRepo(self.__api_key)
         model: Model = model_repo.get_by_name(resolved_model_name)
@@ -1714,7 +1708,7 @@ class Database:
             print(f"Fetching prediction for doc {doc_id} via model '{resolved_model_name}'")
             prediction = model.predict(model_input, model_args=args_copy)
 
-            self.add_annotations(doc_id, [prediction], model.config.name, json_path)
+            self.add_annotations(doc_id, [prediction], (model.config.subcategory or model.config.name), json_path)
 
     def __resolve_model_name_from_backend(self, task_name: str, model_args: Dict[str, Any]) -> str:
         """Call backend to resolve task_name -> concrete model_name."""
