@@ -160,6 +160,10 @@ class ModelRepo:
         except Exception as e:
             print(f"Error fetching Image Classification models: {e}")
         ```
+
+        .. seealso::
+            - :ref:`ModelProvider <modelprovider>`
+        .. #end
         """
         if not provider or not isinstance(provider, ModelProvider):
             raise ValueError("Valid provider is required and must be an instance of ModelProvider.")
@@ -178,11 +182,11 @@ class ModelRepo:
             params["subcategory"] = subcategory
 
         if bdb_constants.debug_mode:
-            logger.debug(f"Requesting models from URL: {url} with params: {params}")
+            print(f"Requesting models from URL: {url} with params: {params}")
 
         response = requests.get(url, params=params)
         if bdb_constants.debug_mode:
-            logger.debug(f"Response status: {response.status_code}, Response text: {response.text}")
+            print(f"Response status: {response.status_code}, Response text: {response.text}")
 
         if response.status_code != 200:
             Utils.handleApiCallFailure(response.json(), response.status_code)
@@ -197,8 +201,8 @@ class ModelRepo:
                     if config:
                         model_list.append(self.__create_model_by_provider(config))
                 except Exception as e:
-                    logger.error(f"Failed to build model config or create model for data: {m_data}. Error: {e}")
-                    logger.error(f"Skipping model...")
+                    print(f"Failed to build model config or create model for data: {m_data}. Error: {e}")
+                    print(f"Skipping model...")
                     continue
         elif isinstance(data, dict) and data:
             try:
@@ -206,27 +210,27 @@ class ModelRepo:
                 if config:
                     model_list.append(self.__create_model_by_provider(config))
             except Exception as e:
-                logger.error(f"Failed to build model config or create model for single data object: {data}. Error: {e}")
+                print(f"Failed to build model config or create model for single data object: {data}. Error: {e}")
         elif not data:
-            logger.info(f"No models found for provider '{provider.value}' with specified filters.")
+            print(f"No models found for provider '{provider.value}' with specified filters.")
 
 
         return model_list
 
-    def get_by_name(self, provider: ModelProvider, model_name: str) -> Optional[Model]:
+    def get_by_name(self, model_name: str, provider: ModelProvider|None = None) -> Optional[Model]:
         """
         Fetches a specific model by its name and provider.
 
         Parameters:
-        - **provider** (`ModelProvider`): The provider of the model to fetch.
         - **model_name** (`str`): The name of the specific model to fetch.
+        - **provider** (`ModelProvider`, optional): The provider of the model to fetch.
 
         Returns:
         - `Model` | `None`: An instance of the Model class if found, otherwise `None`.
 
         Raises:
-        - `ValueError`: If `provider` or `model_name` is `None` or invalid.
-        - An exception (via `Utils.handleApiCallFailure`) if another API error occurs (e.g. server error).
+        - `ValueError`: If `provider` is not of type `ModelProvider` or `model_name` is `None` or invalid.
+        - An exception if another API error occurs (e.g. server error).
 
         Example:
         ```python
@@ -241,8 +245,8 @@ class ModelRepo:
         try:
             # Example 1: Get a specific Hugging Face model
             hf_model = repo.get_by_name(
-                provider=ModelProvider.HUGGING_FACE_MODEL,
                 model_name="my-sentiment-analyzer"
+                provider=ModelProvider.HUGGING_FACE_MODEL,
             )
             if hf_model:
                 print(f"Fetched Hugging Face model: {hf_model.config.name}")
@@ -251,36 +255,45 @@ class ModelRepo:
 
             # Example 2: Get a specific Vertex AI model
             vertex_model = repo.get_by_name(
-                provider=ModelProvider.VERTEX_AI_MODEL,
                 model_name="gemini-pro" # Ensure this model exists
+                provider=ModelProvider.VERTEX_AI_MODEL,
             )
             if vertex_model:
                 print(f"Fetched Vertex AI model: {vertex_model.config.name}")
             else:
                 print("Vertex AI model 'gemini-pro' not found.")
 
-        except Exception as e: # Catch other potential API errors
+        except Exception as e: # Catch other potential errors
             print(f"An error occurred: {e}")
         ```
+
+        .. seealso::
+            - :ref:`ModelProvider <modelprovider>`
+        .. #end
         """
-        if not provider or not isinstance(provider, ModelProvider):
-            raise ValueError("Valid provider is required and must be an instance of ModelProvider.")
+        # The provider must be either None or of type ModelProvider
+        if provider is not None and not isinstance(provider, ModelProvider):
+            raise ValueError("Valid provider is required and must be an instance of ModelProvider or None.")
         if not model_name or not isinstance(model_name, str) or not model_name.strip():
             raise ValueError("Valid model_name is required and must be a non-empty string.")
 
         url = bdb_constants.ML_BACKEND_BASE_URL + bdb_constants.get_models_url
-        params = {"apiKey": self.api_key, "type": provider.value, "name": model_name.strip()}
+        params = {"apiKey": self.api_key, "name": model_name.strip()}
+        if provider:
+            params["type"] = provider.value
 
         if bdb_constants.debug_mode:
-            logger.debug(f"Requesting model by name from URL: {url} with params: {params}")
+            print(f"Requesting model by name from URL: {url} with params: {params}")
 
         response = requests.get(url, params=params)
         if bdb_constants.debug_mode:
-            logger.debug(f"Response status: {response.status_code}, Response text: {response.text}")
+            print(f"Response status: {response.status_code}, Response text: {response.text}")
 
         if response.status_code == 404:
-            logger.info(f"Model '{model_name}' not found for provider '{provider.value}'. API returned 404.")
-            return None
+            if provider:
+                raise Exception(f"Model '{model_name}' not found for provider '{provider.value}'.")
+            else:
+                raise Exception(f"Model '{model_name}' not found.")
         if response.status_code != 200:
             Utils.handleApiCallFailure(response.json(), response.status_code)
 
@@ -288,13 +301,15 @@ class ModelRepo:
 
         if isinstance(model_data_list, list):
             if not model_data_list:
-                logger.info(f"Model '{model_name}' not found for provider '{provider.value}'. API returned with empty list.")
-                return None
+                if provider:
+                    raise Exception(f"Model '{model_name}' not found for provider '{provider.value}'.")
+                else:
+                    raise Exception(f"Model '{model_name}' not found.")
             model_data_item = model_data_list[0]
         elif isinstance(model_data_list, dict) and model_data_list:
              model_data_item = model_data_list
         else:
-            logger.error(f"Unexpected API response format for get_by_name. Data: {model_data_list}")
+            print(f"Unexpected response format for get_by_name. Data: {model_data_list}")
             return None
 
 
@@ -302,7 +317,7 @@ class ModelRepo:
             config = self.__build_model_config(model_data_item)
             return self.__create_model_by_provider(config) if config else None
         except Exception as e:
-            logger.error(f"Failed to build model config or create model for data: {model_data_item}. Error: {e}")
+            print(f"Failed to build model config or create model for data: {model_data_item}. Error: {e}")
             return None
 
     def save(self, model_config: ModelConfig) -> Model:
